@@ -4,7 +4,7 @@ from __future__ import (
     print_function,
     unicode_literals,
 )
-from home import Home
+from .home import Home
 
 
 def main():
